@@ -35,8 +35,7 @@ namespace Oxygen
 
     //__________________________________________________________________
     ArgbHelper::ArgbHelper( void ):
-        _hooksInitialized( false ),
-        _logId( 0 )
+        _hooksInitialized( false )
     {}
 
 
@@ -48,14 +47,6 @@ namespace Oxygen
         _colormapHook.disconnect();
         _styleHook.disconnect();
 
-        if( _logId > 0 )
-        {
-
-            g_log_remove_handler( "GLib-GObject", _logId );
-            g_log_set_handler( "GLib-GObject", G_LOG_LEVEL_CRITICAL, g_log_default_handler, 0L );
-
-        }
-
     }
 
     //_____________________________________________________
@@ -64,21 +55,13 @@ namespace Oxygen
 
         if( _hooksInitialized ) return;
 
-        // lookup relevant signal
-        const guint signalId( g_signal_lookup("style-set", GTK_TYPE_WINDOW ) );
-        if( signalId <= 0 ) return;
+        // colormap hooks
+        if( !_colormapHook.connect( "style-set", (GSignalEmissionHook)colormapHook, 0L ) )
+        { return; }
 
-        // install hooks
-        _colormapHook.connect( "style-set", (GSignalEmissionHook)colormapHook, 0L );
+        // parent-set hook
         _styleHook.connect( "parent-set", (GSignalEmissionHook)styleHook, this );
 
-        /*
-        the installation of "parent-set" hook triggers some glib critical error when destructing ComboBoxEntry.
-        a glib/gtk bug has been filed. In the meanwhile, and since the error is apparently harmless, we simply
-        disable the corresponding log
-        */
-        _logId = g_log_set_handler( "GLib-GObject", G_LOG_LEVEL_CRITICAL, logHandler, 0L );
-
         _hooksInitialized = true;
         return;
 
@@ -142,16 +125,17 @@ namespace Oxygen
         if( GTK_WIDGET_REALIZED( widget ) ) return TRUE;
         #endif
 
-        // cast to window
-        GtkWindow* window( GTK_WINDOW( widget ) );
-
-        // check type hint
-        GdkWindowTypeHint hint = gtk_window_get_type_hint( window );
-
         // screen
         GdkScreen* screen = gdk_screen_get_default();
         if( !screen ) return TRUE;
 
+        // colormap
+        GdkColormap* colormap(gdk_screen_get_rgba_colormap( screen ) );
+        if( !colormap ) return TRUE;
+
+        // hint
+        GtkWindow* window( GTK_WINDOW( widget ) );
+        GdkWindowTypeHint hint = gtk_window_get_type_hint( window );
         if(
             hint == GDK_WINDOW_TYPE_HINT_MENU ||
             hint == GDK_WINDOW_TYPE_HINT_DROPDOWN_MENU ||
@@ -169,7 +153,7 @@ namespace Oxygen
             #endif
 
             // assign argb colormap to widget
-            gtk_widget_set_colormap( widget, gdk_screen_get_rgba_colormap( screen ) );
+            gtk_widget_set_colormap( widget, colormap );
 
         }
 
@@ -196,17 +180,4 @@ namespace Oxygen
 
     }
 
-    //_________________________________________________________
-    void ArgbHelper::logHandler( const gchar* domain, GLogLevelFlags flags, const gchar* message, gpointer data )
-    {
-
-        /*
-        discard all messages containing "IA__gtk_box_reorder_child:"
-        and fallback to default handler otherwise
-        */
-        if( std::string( message ).find( "g_object_ref" ) == std::string::npos )
-        { g_log_default_handler( domain, flags, message, data ); }
-
-    }
-
 }
