@@ -29,6 +29,7 @@
 #include "oxygengeometry.h"
 #include "oxygengtkcellinfo.h"
 #include "oxygengtkgap.h"
+#include "oxygenloghandler.h"
 #include "oxygenmetrics.h"
 #include "oxygenqtsettings.h"
 #include "oxygenshadowhelper.h"
@@ -127,19 +128,19 @@ namespace Oxygen
 
         //! window background
         /*! returns true if window gradient could be rendered */
-        void renderWindowBackground( cairo_t*, GdkWindow*, GtkWidget*, GdkRectangle*, gint, gint, gint, gint, const StyleOptions& = StyleOptions(), TileSet::Tiles = TileSet::Center );
+        bool renderWindowBackground( cairo_t*, GdkWindow*, GtkWidget*, GdkRectangle*, gint, gint, gint, gint, const StyleOptions& = StyleOptions(), TileSet::Tiles = TileSet::Center );
 
-        void renderWindowBackground( GdkWindow* window, GtkWidget* widget, GdkRectangle* r, gint x, gint y, gint w, gint h, const StyleOptions& o = StyleOptions(), TileSet::Tiles tiles= TileSet::Center )
-        { renderWindowBackground( 0L, window, widget, r, x, y, w, h, o, tiles ); }
+        bool renderWindowBackground( GdkWindow* window, GtkWidget* widget, GdkRectangle* r, gint x, gint y, gint w, gint h, const StyleOptions& o = StyleOptions(), TileSet::Tiles tiles= TileSet::Center )
+        { return renderWindowBackground( 0L, window, widget, r, x, y, w, h, o, tiles ); }
 
-        void renderWindowBackground( GdkWindow* window, GdkRectangle* r, gint x, gint y, gint w, gint h, const StyleOptions& o = StyleOptions(), TileSet::Tiles tiles = TileSet::Center)
-        { renderWindowBackground( window, 0L, r, x, y, w, h, o, tiles ); }
+        bool renderWindowBackground( GdkWindow* window, GdkRectangle* r, gint x, gint y, gint w, gint h, const StyleOptions& o = StyleOptions(), TileSet::Tiles tiles = TileSet::Center)
+        { return renderWindowBackground( window, 0L, r, x, y, w, h, o, tiles ); }
 
         //! groupbox background
-        void renderGroupBoxBackground( GdkWindow* window, GtkWidget* widget, GdkRectangle* r, gint x, gint y, gint w, gint h, const StyleOptions& o, TileSet::Tiles tiles = TileSet::Center )
-        { renderGroupBoxBackground( 0L, window, widget, r, x, y, w, h, o, tiles ); }
+        bool renderGroupBoxBackground( GdkWindow* window, GtkWidget* widget, GdkRectangle* r, gint x, gint y, gint w, gint h, const StyleOptions& o, TileSet::Tiles tiles = TileSet::Center )
+        { return renderGroupBoxBackground( 0L, window, widget, r, x, y, w, h, o, tiles ); }
 
-        void renderGroupBoxBackground( cairo_t*, GdkWindow*, GtkWidget*, GdkRectangle*, gint, gint, gint, gint, const StyleOptions&, TileSet::Tiles = TileSet::Center );
+        bool renderGroupBoxBackground( cairo_t*, GdkWindow*, GtkWidget*, GdkRectangle*, gint, gint, gint, gint, const StyleOptions&, TileSet::Tiles = TileSet::Center );
 
         //! menu background
         bool renderMenuBackground( GdkWindow*, GdkRectangle*, gint, gint, gint, gint, const StyleOptions& ) const;
@@ -448,13 +449,16 @@ namespace Oxygen
 
         private:
 
-        // Qt settings
+        //! log handler
+        LogHandler _logHandler;
+
+        //! Qt settings
         QtSettings _settings;
 
-        // helper
+        //! helper
         StyleHelper _helper;
 
-        // animations
+        //! animations
         Animations _animations;
 
         //! argb helper
